==> aspectran-core-5.1.0-sources.jar: com/aspectran/core/context/rule/parser/ActivityContextParserException.java <==
/*
 * Copyright (c) 2008-2018 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.context.rule.parser;

import com.aspectran.core.context.AspectranCheckedException;

/**
 * This exception is thrown when ActivityContext parsing fails.
 * 
 * <p>Created: 2008. 01. 07 AM 3:35:55</p>
 */
public class ActivityContextParserException extends AspectranCheckedException {

    /** @serial */
    private static final long serialVersionUID = 5702282474852901391L;

    /**
     * Simple constructor.
     */
    public ActivityContextParserException() {
        super();
    }

    /**
     * Constructor to create exception with a message.
     *
     * @param msg the specific message
     */
    public ActivityContextParserException(String msg) {
        super(msg);
    }

    /**
     * Constructor to create exception to wrap another exception.
     *
     * @param cause the real cause of the exception
     */
    public ActivityContextParserException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructor to create exception to wrap another exception and pass a message.
     *
     * @param msg the specific message
     * @param cause the real cause of the exception
     */
    public ActivityContextParserException(String msg, Throwable cause) {
        super(msg, cause);
    }

}

==> aspectran-core-6.13.3-sources.jar: com/aspectran/core/context/rule/parser/ActivityContextParserException.java <==
/*
 * Copyright (c) 2008-2021 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.context.rule.parser;

/**
 * This exception is thrown when ActivityContext parsing fails.
 * 
 * <p>Created: 2008. 01. 07 AM 3:35:55</p>
 */
public class ActivityContextParserException extends Exception {

    /** @serial */
    private static final long serialVersionUID = 5702282474852901391L;

    /**
     * Simple constructor.
     */
    public ActivityContextParserException() {
        super();
    }

    /**
     * Constructor to create exception with a message.
     *
     * @param msg the specific message
     */
    public ActivityContextParserException(String msg) {
        super(msg);
    }

    /**
     * Constructor to create exception to wrap another exception.
     *
     * @param cause the real cause of the exception
     */
    public ActivityContextParserException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructor to create exception to wrap another exception and pass a message.
     *
     * @param msg the specific message
     * @param cause the real cause of the exception
     */
    public ActivityContextParserException(String msg, Throwable cause) {
        super(msg, cause);
    }

}
